@@ -654,7 +654,7 @@ class BucketDeploymentProps:
         if isinstance(metadata, dict):
             metadata = UserDefinedObjectMetadata(**metadata)
         if isinstance(vpc_subnets, dict):
-            vpc_subnets = SubnetSelection(**vpc_subnets)
+            vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if __debug__:
             type_hints = typing.get_type_hints(BucketDeploymentProps.__init__)
             check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
